@@ -1,6 +1,3 @@
-import uuid
-import threading
-import time
 import logging
 import grpc
 
@@ -13,7 +10,6 @@ logger = logging.getLogger(__name__)
 
 class AlgorithmDaemon:
     __instance = None
-    __client_identity = WorkerIdentity
 
     @staticmethod
     def get_instance():
@@ -28,7 +24,7 @@ class AlgorithmDaemon:
             AlgorithmDaemon.__instance = self
 
         logger.info(f"Instantiate daemon {WorkerIdentity}, "
-                    f" connection agent service {GrpcHost}:{GrpcPort}")
+                    f" connect agent service {GrpcHost}:{GrpcPort}")
         self.__channel = grpc.insecure_channel(
             f'{GrpcHost}:{GrpcPort}')
         self.__worker_stub = WorkerBrokerStub(
@@ -37,7 +33,9 @@ class AlgorithmDaemon:
         self.__worker_stub.ReportStatus(ReportStatusRequest(
             clientAddress=WorkerIdentity,
             status=ReportStatusRequest.Pending), timeout=3)
+        logger.info("report status pending.")
         self.__establist_connect()
+        logger.info("establisted connection.")
 
     def shutdown(self):
         logger.info("Daemon ready to shutdown.")
@@ -47,11 +45,12 @@ class AlgorithmDaemon:
             status=ReportStatusRequest.Completed), timeout=3)
 
     def __establist_connect(self):
-        logger.info("Established connection to agent service.")
+        logger.info("Establishing connection to agent service.")
         # pylint: disable=maybe-no-member
         self.__worker_stub.ReportStatus(ReportStatusRequest(
             clientAddress=WorkerIdentity,
             status=ReportStatusRequest.Running), timeout=3)
+        logger.info("report status running.")
 
     def report_progress(self, progress):
         if progress < 0 or progress > 1:
